#include <avr/io.h>
#include "USART.h"


/* Function  USART_Init 

	Bauds : the baud rate of the serial link

Initialize the serial link of the processor
Set the pin RXD as input and TXD as output
Set baud rate and configuration of the module
*/

void USART_Init (unsigned int Bauds)
{

	// Configure the direction of the pins RXD and TXD
	RXD_INPUT		
	TXD_OUTPUT
	// Set TXD to 0
	TXD_0			
	/*Set baud rate */
	UBRR0H = (unsigned char)((F_CPU/16/Bauds-1)>>8);
	UBRR0L = (unsigned char)(F_CPU/16/Bauds-1);
	/* Enable receiver and transmitter */
	UCSR0B = (1<<RXEN0)|(1<<TXEN0);
	/* Set frame format: 8data, 2stop bit */
	UCSR0C = (1<<USBS0)|(3<<UCSZ00);
}





/* Function USART_Send_Char
	
	data : Character to transmit on the serial link

Send a char on the serial link
*/

void USART_Send_Char( char data )
{
	/* Wait for empty transmit buffer */
	while ( !( UCSR0A & (1<<UDRE0)) )
	;
	/* Put data into buffer, sends the data */
	UDR0 = data;
}





/* Function USART_Send_Text

	Text : string to send on the USART

Send a string on the serial link
*/

void USART_Send_Text(char* Text)
{
	while (*Text!=0)
	{
		USART_Send_Char (*Text);
		Text++;
	}
}



/* Function USART_Receive()

	Return the received parameter

Wait for data on the serial link and return its value
*/

char USART_Receive( void )
{
	/* Wait for data to be received */
	while ( !(UCSR0A & (1<<RXC0)) );
	/* Get and return received data from buffer */
	return UDR0;
}
